@@ -11,7 +11,6 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import json
 import logging
 import sys
 
@@ -39,7 +38,6 @@ logger = get_default_logger()
 @app.route('/globals', methods=['GET', 'POST'])
 def handle_globals():
     if request.method == 'POST':
-        print(request.json)
         for var_name, var_info in global_variables.items():
             if var_name in request.json:
                 global_variables[var_name]['func'](request.json[var_name])
@@ -55,14 +53,19 @@ def run_function(group, func_name):
     # do a urldecode on the group
     from urllib.parse import unquote
     group = unquote(group)
-    if group in ui_enabled_functions and func_name in list(map(lambda x: x['name'], ui_enabled_functions[group])):
-        func_info = list(filter(lambda x: x['name'] == func_name, ui_enabled_functions[group]))[0]
-        func = func_info['function']
+    if group in ui_enabled_functions and func_name in list(map(lambda x: x.name, ui_enabled_functions[group])):
+        func_info = list(filter(lambda x: x.name == func_name, ui_enabled_functions[group]))[0]
+        func = func_info.function
         try:
             args = request.json
-            result = func(**args)
+            final_args = dict()
+            for param_info in func_info.parameters:  # Assuming you have parameter info
+                final_args[param_info.name] = param_info.type_handler(args.get(param_info.name), param_info.default)
+
+            result = func(**final_args)
             return jsonify(result)
         except Exception as e:
+            logger.exception(e)
             return jsonify({'error': str(e)}), 400
     else:
         return jsonify({'error': 'Function not found'}), 404
@@ -80,7 +83,7 @@ def start_server(host: str | None = None,
     for group, func_list in ui_enabled_functions.items():
         functions += f"Functions under ({group}):\n"
         for func in func_list:
-            functions += f"\t{func['name']}\n"
+            functions += f"\t{func.name}\n"
 
     logger.info(f"Registered functions:\n{functions}")
     app.run(debug=debug, host=host, port=port)
